==> unicore-ucc6-5.0.0-1.src.tar.gz: ucc-core/src/main/java/de/fzj/unicore/ucc/actions/Resolve.java <==
package de.fzj.unicore.ucc.actions;

import java.util.HashMap;
import java.util.Map;

import org.apache.commons.cli.OptionBuilder;
import org.w3.x2005.x08.addressing.EndpointReferenceType;

import de.fzj.unicore.uas.client.StorageClient;
import de.fzj.unicore.ucc.MessageWriter;
import de.fzj.unicore.ucc.helpers.IResolve;
import de.fzj.unicore.ucc.helpers.Location;
import de.fzj.unicore.wsrflite.xmlbeans.client.IRegistryQuery;
import eu.unicore.security.util.client.IClientProperties;

/**
 * resolves a remote SMS location given in the
 * "abstract" form "u6://..." or "unicore6://"<br/>
 * 
 * @see Location
 *
 * @author schuller
 */
public class Resolve extends ActionBase {

	protected Location targetDesc;

	protected boolean full;
	
	private static Map<String,IResolve>resolvers=new HashMap<String,IResolve>();
	
	/**
	 * register a resolver
	 * @param uriScheme - the URI scheme that the resolver can handle. This is only used
	 * internally as a hash key
	 * @param resolver - the resolver
	 */
	public static void addResolver(String uriScheme, IResolve resolver){
		resolvers.put(uriScheme,resolver);
	}
	
	@Override
	@SuppressWarnings("all")
	protected void createOptions() {
		super.createOptions();
		getOptions().addOption(OptionBuilder.withLongOpt("full")
				.withDescription("Print full file URI")
				.isRequired(false)
				.create("f")
		);
	}
	/**
	 * resolve the given URI using the registered resolvers
	 * @param uri
	 * @param registry
	 * @param security
	 * @param messageWriter
	 * @return
	 */
	public static Location resolve(String uri, IRegistryQuery registry, IClientProperties security, MessageWriter messageWriter){
		Location loc=null;
		for(IResolve r: resolvers.values()){
			loc=r.resolve(uri,registry,security,messageWriter);
			if(loc!=null)break;
		}
		//fallback to default location
		if(loc==null)loc=new Location(uri,registry,security,messageWriter);
		return loc;
	}
	
	@Override
	public void process(){
		super.process();
		String target =getCommandLine().getArgs()[1];;
		targetDesc=resolve(target,registry,securityProperties,this);
		full=getBooleanOption("full", "f");
		EndpointReferenceType e=EndpointReferenceType.Factory.newInstance();
		e.addNewAddress().setStringValue(targetDesc.getSmsEpr());
		try{
			StorageClient sms=new StorageClient(targetDesc.getSmsEpr(),e,securityProperties);
			verbose("SMS "+targetDesc.getSmsEpr()
					+" contacted, server reply: servertime="+sms.getCurrentTime());
		}catch(Exception ex){
			error("Can't contact storage service.",ex);
			endProcessing(ERROR);
		}
		String result=full? targetDesc.getUnicore6URI():e.getAddress().getStringValue();
		message(result);
	}
	
	@Override
	public String getName() {
		return "resolve";
	}

	@Override
	public String getSynopsis() {
		return "Resolves a remote location given in the form 'unicore6://SITE/location/file_path'," +
				"and prints the storage URL. Use the '-f' option to print the full UNICORE file URI "
				+"of the form PROTOCOL:StorageURL#/file_path";
	}
	
	@Override
	public String getDescription(){
		return "resolve remote location";
	}
	
	@Override
	public String getArgumentList(){
		return "[unicore6://SITENAME/[JobId|StorageName]]";
	}
	@Override
	public String getCommandGroup(){
		return "Data management";
	}
}

==> unicore-ucc6-6.0.0-0.src.tar.gz: ucc-core/src/main/java/de/fzj/unicore/ucc/actions/Resolve.java <==
package de.fzj.unicore.ucc.actions;

import java.util.HashMap;
import java.util.Map;

import org.apache.commons.cli.OptionBuilder;
import org.w3.x2005.x08.addressing.EndpointReferenceType;

import de.fzj.unicore.uas.client.StorageClient;
import de.fzj.unicore.ucc.MessageWriter;
import de.fzj.unicore.ucc.helpers.IResolve;
import de.fzj.unicore.ucc.helpers.Location;
import de.fzj.unicore.wsrflite.xmlbeans.client.IRegistryQuery;
import eu.unicore.util.httpclient.IClientConfiguration;

/**
 * resolves a remote SMS location given in the
 * "abstract" form "u6://..." or "unicore6://"<br/>
 * 
 * @see Location
 *
 * @author schuller
 */
public class Resolve extends ActionBase {

	protected Location targetDesc;

	protected boolean full;
	
	private static Map<String,IResolve>resolvers=new HashMap<String,IResolve>();
	
	/**
	 * register a resolver
	 * @param uriScheme - the URI scheme that the resolver can handle. This is only used
	 * internally as a hash key
	 * @param resolver - the resolver
	 */
	public static void addResolver(String uriScheme, IResolve resolver){
		resolvers.put(uriScheme,resolver);
	}
	
	@Override
	@SuppressWarnings("all")
	protected void createOptions() {
		super.createOptions();
		getOptions().addOption(OptionBuilder.withLongOpt("full")
				.withDescription("Print full file URI")
				.isRequired(false)
				.create("f")
		);
	}
	/**
	 * resolve the given URI using the registered resolvers
	 * @param uri
	 * @param registry
	 * @param security
	 * @param messageWriter
	 * @return Location object corresponding to the given URI
	 */
	public static Location resolve(String uri, IRegistryQuery registry, IClientConfiguration security, MessageWriter messageWriter){
		Location loc=null;
		for(IResolve r: resolvers.values()){
			loc=r.resolve(uri,registry,security,messageWriter);
			if(loc!=null)break;
		}
		//fallback to default location
		if(loc==null)loc=new Location(uri,registry,security,messageWriter);
		return loc;
	}
	
	@Override
	public void process(){
		super.process();
		String target =getCommandLine().getArgs()[1];;
		targetDesc=resolve(target,registry,securityProperties,this);
		full=getBooleanOption("full", "f");
		EndpointReferenceType e=EndpointReferenceType.Factory.newInstance();
		e.addNewAddress().setStringValue(targetDesc.getSmsEpr());
		try{
			StorageClient sms=new StorageClient(targetDesc.getSmsEpr(),e,securityProperties);
			verbose("SMS "+targetDesc.getSmsEpr()
					+" contacted, server reply: servertime="+sms.getCurrentTime());
		}catch(Exception ex){
			error("Can't contact storage service.",ex);
			endProcessing(ERROR);
		}
		String result=full? targetDesc.getUnicore6URI():e.getAddress().getStringValue();
		message(result);
	}
	
	@Override
	public String getName() {
		return "resolve";
	}

	@Override
	public String getSynopsis() {
		return "Resolves a remote location given in the form 'unicore6://SITE/location/file_path'," +
				"and prints the storage URL. Use the '-f' option to print the full UNICORE file URI "
				+"of the form PROTOCOL:StorageURL#/file_path";
	}
	
	@Override
	public String getDescription(){
		return "resolve remote location";
	}
	
	@Override
	public String getArgumentList(){
		return "[unicore6://SITENAME/[JobId|StorageName]]";
	}
	@Override
	public String getCommandGroup(){
		return "Data management";
	}
}
